from dbnd import parameter
from dbnd._core.task.config import Config


class LivySparkConfig(Config):
    # we don't want spark class to inherit from this one, as it should has Config behaviour
    _conf__task_family = "livy"
    _conf__help_description = "livy configuration"

    url = parameter(description="livy connection url (for example: http://livy:8998)")[
        str
    ]

    def get_spark_ctrl(self, task_run):
        from dbnd_spark.livy.livy_spark import LivySparkCtrl

        return LivySparkCtrl(task_run)



import dbnd

from dbnd import register_config_cls
from dbnd_spark.livy.livy_spark_config import LivySparkConfig


@dbnd.hookimpl
def dbnd_setup_plugin():
    from dbnd_spark.local.local_spark_config import SparkLocalEngineConfig

    register_config_cls(SparkLocalEngineConfig)
    register_config_cls(LivySparkConfig)

    try:
        from dbnd_spark.targets import register_targets

        register_targets()
    except ImportError:
        pass
